==> qtjambi-debuginfo-macos-5.15.18.jar: sources/QtJambiGui/QPdfWriter_shell.h <==
#ifndef QPDFWRITER_SHELL_H
#define QPDFWRITER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qpdfwriter.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpagesize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtJambi/RegistryAPI>


class QPdfWriter_shell : public QPdfWriter, public QtJambiShellInterface
{
public:
    QPdfWriter_shell(QIODevice* device0);
    QPdfWriter_shell(const QString& filename0);
    ~QPdfWriter_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric id0) const override;
    bool newPage() override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void setMargins(const QPagedPaintDevice::Margins& m0) override;
    void setPageSize(QPagedPaintDevice::PageSize size0) override;
    void setPageSizeMM(const QSizeF& size0) override;
    QPainter* sharedPainter() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPdfWriter_access : public QPdfWriter
{
    jobject __qt_devicePageLayout(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0) const;
    jboolean __qt_newPage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_paintEngine(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    void __qt_setMargins_cref_QPagedPaintDevice_Margins(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID m0);
    void __qt_setPageSize_QPagedPaintDevice_PageSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint size0);
    void __qt_setPageSizeMM_cref_QSizeF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0);
    jobject __qt_sharedPainter(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPDFWRITER_SHELL_H

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QPdfWriter_shell.h <==
#ifndef QPDFWRITER_SHELL_H
#define QPDFWRITER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qpdfwriter.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qiodevice.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpagelayout.h>
#include <QtGui/qpagesize.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtJambi/RegistryAPI>


class QPdfWriter_shell : public QPdfWriter, public QtJambiShellInterface
{
public:
    QPdfWriter_shell(QIODevice* device0);
    QPdfWriter_shell(const QString& filename0);
    ~QPdfWriter_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void initPainter(QPainter* painter0) const override;
    int metric(QPaintDevice::PaintDeviceMetric id0) const override;
    bool newPage() override;
    QPaintEngine* paintEngine() const override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void setMargins(const QPagedPaintDevice::Margins& m0) override;
    void setPageSize(QPagedPaintDevice::PageSize size0) override;
    void setPageSizeMM(const QSizeF& size0) override;
    QPainter* sharedPainter() const override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QPdfWriter_access : public QPdfWriter
{
    jobject __qt_devicePageLayout_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_initPainter_QPainter_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID painter0) const;
    jint __qt_metric_QPaintDevice_PaintDeviceMetric_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint id0) const;
    jboolean __qt_newPage(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jobject __qt_paintEngine_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_redirected_QPoint_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID offset0) const;
    void __qt_setMargins_cref_QPagedPaintDevice_Margins(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID m0);
    void __qt_setPageSize_QPagedPaintDevice_PageSize(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint size0);
    void __qt_setPageSizeMM_cref_QSizeF(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID size0);
    jobject __qt_sharedPainter_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QPDFWRITER_SHELL_H
